@@ -4,15 +4,15 @@ import requests
 from logger.common.configuration.httpClientConfig import HttClientConfig
 from logger.common.dto.logCreateDto import LogCreateDto
 from logger.common.dto.logRequestDto import LogRequestDto
-from logger.common.enum.logLevel import LogLevel
-from logger.common.enum.platform import Platform
+from logger.common.enums.logLevel import LogLevel
+from logger.common.enums.platform import Platform
+
 
 with requests.Session() as session:
     session.headers.update({
         'Content-Type': 'application/json',
     })
 
-
     def init(api_key):
         response = session.post(f'{HttClientConfig.alertNowURL}/users/sign-in-with-api-key/{api_key}')
         if response.status_code != 200:
@@ -24,16 +24,14 @@ with requests.Session() as session:
 
         return 'Connection was initialized successfully'
 
-
     def info(message):
         return create_log(LogCreateDto(LogLevel.INFO.value, message))
 
-
     def error(occurred_error):
         return create_log(LogCreateDto(LogLevel.ERROR.value, json.dumps(vars(occurred_error))))
 
-
     def create_log(log_create_dto):
         log_request_dto = LogRequestDto(Platform.PYTHON.value, json.dumps(vars(log_create_dto)))
-        response = session.post(f'{HttClientConfig.alertNowURL}/logs/create', data=json.dumps(vars(log_request_dto)))
+        response = session.post(f'{HttClientConfig.alertNowURL}/logs/create',
+                                data=json.dumps(vars(log_request_dto)))
         return response
